Skip to contents

Returns a tibble with per-sample sampling details including number of cells, sampling time, and clone proportions. Optionally filtered by SPN and/or sample.

Usage

get_sampling_information(spn = NULL, sample = NULL)

Arguments

spn

SPN identifier, e.g. "SPN01". If NULL, returns all SPNs.

sample

Sample identifier. If NULL, returns all samples.

Value

A tibble with columns: SPN, Sample, Number of cells, Sampling time, Clone 1 proportionClone 7 proportion.

Examples

if (FALSE) { # \dontrun{
get_sampling_information()
get_sampling_information("SPN01")
get_sampling_information("SPN01", sample = "1.1")
} # }