Get SCOUT sample metadata
get_metadata.RdReturns a tibble with one row per sample, containing identifiers and high-level annotations (tumour type, clonal composition, FGA/FGS, clonal class, hypermutant status, WGD, and signature context).

get_metadata.RdReturns a tibble with one row per sample, containing identifiers and high-level annotations (tumour type, clonal composition, FGA/FGS, clonal class, hypermutant status, WGD, and signature context).