Get the local path to Sarek results for a SCOUT SPN
get_sarek_results.RdDownloads and extracts the Sarek archive for a given SPN and purity (if not already cached) and returns the path to the extracted directory.
Usage
get_sarek_results(
spn,
purity,
record_id = .scout_record_id(spn, purity, type = "sarek"),
cache_dir = .scout_cache_dir(spn, purity)
)