Skip to contents

Downloads and unzips the Sarek archive from the SPN's Zenodo record (if not already cached) and returns the path to the extracted directory.

Usage

get_sarek_results(
  spn,
  record_id = .scout_record_id(spn),
  cache_dir = .scout_cache_dir(spn)
)

Arguments

spn

SPN identifier, e.g. "SPN01".

record_id

Zenodo record ID for this SPN.

cache_dir

Local directory to cache downloaded files. Defaults to ~/.cache/SCOUT/<spn>/.

Value

Invisible path to the directory containing the Sarek results.

Examples

if (FALSE) { # \dontrun{
path <- get_sarek_results("SPN01", record_id = "1234567")
list.files(path)
} # }