Get the local path to Sarek results for a SCOUT SPN
get_sarek_results.RdDownloads and unzips the Sarek archive from the SPN's Zenodo record (if not already cached) and returns the path to the extracted directory.
Usage
get_sarek_results(
spn,
record_id = .scout_record_id(spn),
cache_dir = .scout_cache_dir(spn)
)Examples
if (FALSE) { # \dontrun{
path <- get_sarek_results("SPN01", record_id = "1234567")
list.files(path)
} # }