Get the local path to tumourevo results for a SCOUT SPN
get_tumourevo_results.RdDownloads and unzips the tumourevo archive from the SPN's Zenodo record (if not already cached) and returns the path to the extracted directory.
Usage
get_tumourevo_results(
spn,
record_id = .scout_record_id(spn),
cache_dir = .scout_cache_dir(spn)
)Examples
if (FALSE) { # \dontrun{
path <- get_tumourevo_results("SPN01", record_id = "1234567")
list.files(path)
} # }